Tests exceptions
================

.. report:: Trackers.ErrorInTracker1
   :render: bar-plot

   A tracker which creates an error

.. report:: Trackers.ErrorInTracker2
   :render: bar-plot

   A tracker which creates an error

.. report:: Trackers.ErrorInTracker3
   :render: bar-plot

   A tracker which creates an error

.. report:: Trackers.UnknownTracker
   :render: bar-plot

   A missing tracker

.. report:: Trackers.LabeledDataExample
   :render: unknown-renderer

   An unknown renderer

.. report:: Trackers.LabeledDataExample

   A missing renderer

.. report:: Trackers.LabeledDataExample
   :render: bar-plot
   :transform: unknown-transform   

   An unknown transform

Test warnings
=============

.. report:: Trackers.EmptyTracker
   :render: table
   
   A tracker which is empty
